"use strict";(self.webpackChunkbqscales=self.webpackChunkbqscales||[]).push([[911],{911:(e,a,r)=>{r.r(a),r.d(a,{Albers:()=>M.Tb,AlbersModel:()=>w.hP,AlbersUSA:()=>M.YR,AlbersUSAModel:()=>w.X6,ColorScale:()=>u.q,ColorScaleModel:()=>d.l,DateColorScale:()=>k.T,DateColorScaleModel:()=>h.E,DateScale:()=>S.I,DateScaleModel:()=>y._,EquiRectangular:()=>M.VW,EquiRectangularModel:()=>w.kK,GeoScale:()=>M.aC,GeoScaleModel:()=>w.l,Gnomonic:()=>M.XU,GnomonicModel:()=>w.wz,LinearScale:()=>c.f,LinearScaleModel:()=>o.t,LogScale:()=>x.Y,LogScaleModel:()=>f.V,MODULE_NAME:()=>l.oF,MODULE_VERSION:()=>l.Y2,Mercator:()=>M.Hk,MercatorModel:()=>w.Cq,OrdinalColorScale:()=>m.O,OrdinalColorScaleModel:()=>g.p,OrdinalScale:()=>b.J,OrdinalScaleModel:()=>p.U,Orthographic:()=>M.YH,OrthographicModel:()=>w.bh,SEMVER_RANGE:()=>l.$E,Scale:()=>i.C,ScaleModel:()=>n.K,Stereographic:()=>M.Hg,StereographicModel:()=>w.Fd,colorbrewer:()=>t.G,convertToDate:()=>o.k,cycleColors:()=>s.Tw,cycleColorsFromScheme:()=>s.f2,getLinearScale:()=>s.lR,getLinearScaleRange:()=>s.Uk,getOrdinalScale:()=>s.mu,getOrdinalScaleRange:()=>s.T7,isColorScale:()=>u.c,isDateColorScale:()=>k.N,isDateScale:()=>S.E,isLinearScale:()=>c.r,isLogScale:()=>x.A,isOrdinalScale:()=>b.a});var l=r(657),t=r(486),s=r(145),n=r(639),i=r(167),o=r(19),c=r(10),p=r(413),b=r(291),d=r(929),u=r(94),m=r(207),g=r(137),h=r(383),k=r(884),y=r(292),S=r(900),f=r(865),x=r(287),w=r(580),M=r(667)},657:(e,a,r)=>{r.d(a,{$E:()=>s,Y2:()=>t,oF:()=>n});const l=r(147),t=l.version,s="^"+t,n=l.name},147:e=>{e.exports=JSON.parse('{"name":"bqscales","version":"0.2.3","description":"Grammar of Graphics in Python","keywords":["jupyter","jupyterlab","jupyterlab-extension","widgets"],"files":["lib/**/*.js","lib/**/*.ts","dist/*.js"],"homepage":"https://github.com/bqplot/bqscales","bugs":{"url":"https://github.com/bqplot/bqscales/issues"},"license":"Apache","author":{"name":"Bqplot development team"},"main":"lib/index.js","types":"./lib/index.d.ts","repository":{"type":"git","url":"https://github.com/bqplot/bqscales"},"scripts":{"build":"yarn run build:lib && yarn run build:nbextension && yarn run build:labextension","build:lib":"tsc","build:nbextension":"webpack","build:labextension":"jupyter labextension build .","clean":"yarn run clean:lib && yarn run clean:nbextension && yarn run clean:labextension","clean:lib":"rimraf lib","clean:nbextension":"rimraf bqscales/nbextension/static/index.js","clean:labextension":"rimraf bqscales/labextension","prepack":"npm run build","test":"npm run test:chrome","test:chrome":"karma start --browsers=Chrome tests/karma.conf.js","test:debug":"karma start --browsers=Chrome --singleRun=false --debug=true tests/karma.conf.js","test:firefox":"karma start --browsers=Firefox tests/karma.conf.js","test:ie":"karma start --browsers=IE tests/karma.conf.js","watch":"npm-run-all -p watch:*","watch:lib":"tsc -w","watch:nbextension":"webpack --watch","prettier:check":"prettier src --check","prettier:fix":"prettier src --write","eslint:check":"eslint src --ext .ts","eslint:fix":"eslint src --ext .ts --fix"},"dependencies":{"@jupyter-widgets/base":"^2.0.2 || ^3 || ^4.0.0","d3-array":"^2.4.0","d3-geo":"^1.11.9","d3-scale":"^3.2.1","underscore":"^1.9.2"},"devDependencies":{"@jupyterlab/builder":"^3.0.0","@phosphor/application":"^1.7.3","@phosphor/widgets":"^1.9.3","@types/expect.js":"^0.3.29","@types/d3-array":"^2.0.0","@types/d3-geo":"^1.11.1","@types/d3-scale":"^2.1.1","@types/mocha":"^7.0.1","@types/node":"^13.7.0","@types/webpack-env":"^1.15.1","@typescript-eslint/eslint-plugin":"^4.19.0","@typescript-eslint/parser":"^4.19.0","babel-polyfill":"^6.26.0","expect.js":"^0.3.1","eslint":"^7.22.0","eslint-config-prettier":"^8.1.0","eslint-plugin-prettier":"^3.3.1","eslint-config-standard":"^16.0.2","eslint-plugin-import":"^2.22.1","eslint-plugin-node":"^11.1.0","eslint-plugin-promise":"^4.2.1","fs-extra":"^7.0.0","karma":"^6.3.14","karma-chrome-launcher":"^3.1.0","karma-firefox-launcher":"^1.3.0","karma-ie-launcher":"^1.0.0","karma-mocha":"^1.3.0","karma-mocha-reporter":"^2.2.5","karma-typescript":"^4.1.1","karma-typescript-es6-transform":"^4.1.1","mkdirp":"^0.5.1","mocha":"^7.0.1","npm-run-all":"^4.1.3","prettier":"^2.2.1","rimraf":"^2.6.2","source-map-loader":"^0.2.4","ts-loader":"^6.2.1","typescript":"^3.7.5","webpack":"^5.61","webpack-cli":"^4"},"jupyterlab":{"extension":"lib/plugin","webpackConfig":"webpack.lab.config.js","outputDir":"bqscales/labextension","sharedPackages":{"@jupyter-widgets/base":{"bundled":false,"singleton":true},"d3-array":{"bundled":true,"singleton":false},"d3-geo":{"bundled":true,"singleton":false},"d3-scale":{"bundled":true,"singleton":false},"underscore":{"bundled":true,"singleton":false}}}}')}}]);